@@ -122,7 +122,7 @@ class ExportJob:
 class GoodData:
     """Main class for interacting with GoodData API."""
 
-    def __init__(self, user, password, domain, pid, nocache=False):
+    def __init__(self, user, password, domain, pid):
         """Initiate GoodData API and login
 
         Args:
@@ -130,7 +130,6 @@ class GoodData:
             password (str): user password
             domain (str): GoodData API domain (the part before .gooddata.com (e.g. secure))
             pid (str): project id
-            nocache (bool, optional): If True, discard any possible existing cache. Defaults to False.
         """
         self.last_login = None
         self.session = RetrySession()
@@ -141,7 +140,6 @@ class GoodData:
         self.logger = getLogger(__name__)
         self.profile = None
         self.login()
-        self.nocache = nocache
         self.headers = {
             "Content-Type": "application/json",
             "Accept": "application/json",
@@ -156,13 +154,8 @@ class GoodData:
         self.datasets_on_dashboard = {}
         self.processed = []
         self.processed_objects = {}
-        cache = {}
-        if not self.pid in cache:
-            self.metadata = {}
-            self.dataset_members = {}
-        else:
-            self.metadata = cache[self.pid]["metadata"]
-            self.dataset_members = cache[self.pid]["dataset_members"]
+        self.metadata = {}
+        self.dataset_members = {}
 
     def login(self):
         """Login to GoodData and obtain tokens"""
@@ -183,88 +176,82 @@ class GoodData:
         self.profile = response.json()["userLogin"]["profile"]
         self.last_login = datetime.now()
 
-    def list_dashboards(self, nocache=False):
+    def list_dashboards(self):
         """List all dashboards
 
         Returns:
             list: List of dictionaries containing dashboard metadata
         """
-        if not self.dashboards or nocache:
-            self.login()
-            url = _url(self.domain, "gdc/md/{pid}/query/projectdashboards".format(pid=self.pid))
-            response = self.session.get(url, headers=self.headers)
-            self.dashboards = response.json()["query"]["entries"]
+        self.login()
+        url = _url(self.domain, "gdc/md/{pid}/query/projectdashboards".format(pid=self.pid))
+        response = self.session.get(url, headers=self.headers)
+        self.dashboards = response.json()["query"]["entries"]
         return self.dashboards
 
-    def list_kpidashboards(self, nocache=False):
+    def list_kpidashboards(self):
         """List all KPI Dashboards
 
         Returns:
             list: List of dictionaries containing dashboard metadata
         """
-        if not self.kpidashboards or nocache:
-            self.login()
-            url = _url(
-                self.domain,
-                "gdc/md/{pid}/query/analyticaldashboard".format(pid=self.pid),
-            )
-            response = self.session.get(url, headers=self.headers)
-            self.kpidashboards = response.json()["query"]["entries"]
+        self.login()
+        url = _url(
+            self.domain,
+            "gdc/md/{pid}/query/analyticaldashboard".format(pid=self.pid),
+        )
+        response = self.session.get(url, headers=self.headers)
+        self.kpidashboards = response.json()["query"]["entries"]
         return self.kpidashboards
 
-    def list_reports(self, nocache=False):
+    def list_reports(self):
         """List all reports
 
         Returns:
             list: List of dictionaries containing report metadata
         """
-        if not self.reports or nocache:
-            self.login()
-            url = _url(self.domain, "gdc/md/{pid}/query/reports".format(pid=self.pid))
-            response = self.session.get(url, headers=self.headers)
-            self.reports = response.json()["query"]["entries"]
+        self.login()
+        url = _url(self.domain, "gdc/md/{pid}/query/reports".format(pid=self.pid))
+        response = self.session.get(url, headers=self.headers)
+        self.reports = response.json()["query"]["entries"]
         return self.reports
 
-    def list_kpis(self, nocache=False):
+    def list_kpis(self):
         """List all visualizationobjects
 
         Returns:
             list: List of dictionaries containing kpi metadata
         """
-        if not self.kpis or nocache:
-            self.login()
-            url = _url(
-                self.domain,
-                "gdc/md/{pid}/query/visualizationobjects".format(pid=self.pid),
-            )
-            response = self.session.get(url, headers=self.headers)
-            self.kpis = response.json()["query"]["entries"]
+        self.login()
+        url = _url(
+            self.domain,
+            "gdc/md/{pid}/query/visualizationobjects".format(pid=self.pid),
+        )
+        response = self.session.get(url, headers=self.headers)
+        self.kpis = response.json()["query"]["entries"]
         return self.kpis
 
-    def list_datasets(self, nocache=False):
+    def list_datasets(self):
         """List all project datasets
 
         Returns:
             list: List of dictionaries containing dataset metadata
         """
-        if not self.datasets or nocache:
-            self.login()
-            url = _url(self.domain, "gdc/md/{pid}/query/datasets".format(pid=self.pid))
-            response = self.session.get(url, headers=self.headers)
-            self.datasets = response.json()["query"]["entries"]
+        self.login()
+        url = _url(self.domain, "gdc/md/{pid}/query/datasets".format(pid=self.pid))
+        response = self.session.get(url, headers=self.headers)
+        self.datasets = response.json()["query"]["entries"]
         return self.datasets
 
-    def list_metrics(self, nocache=False):
+    def list_metrics(self):
         """List all project metrics
 
         Returns:
             list: List of dictionaries containing metric metadata
         """
-        if not self.metrics or nocache:
-            self.login()
-            url = _url(self.domain, "gdc/md/{pid}/query/metrics".format(pid=self.pid))
-            response = self.session.get(url, headers=self.headers)
-            self.metrics = response.json()["query"]["entries"]
+        self.login()
+        url = _url(self.domain, "gdc/md/{pid}/query/metrics".format(pid=self.pid))
+        response = self.session.get(url, headers=self.headers)
+        self.metrics = response.json()["query"]["entries"]
         return self.metrics
 
     def _find_nested_metric(self, node):
@@ -349,17 +336,16 @@ class GoodData:
             url = _url(self.domain, "gdc/account/profile/{}".format(user_link))
         return self.session.get(url).json()
 
-    def list_projects(self, nocache=False):
+    def list_projects(self):
         """List all projects authenticated by current user.
 
         Returns
             list: List of dictionaries containing project metadata
         """
-        if not self.projects or nocache:
-            self.login()
-            url = _url(self.domain, "gdc/md")
-            response = self.session.get(url, headers=self.headers)
-            self.projects = [entry for entry in response.json()["about"]["links"] if entry["category"] == "project"]
+        self.login()
+        url = _url(self.domain, "gdc/md")
+        response = self.session.get(url, headers=self.headers)
+        self.projects = [entry for entry in response.json()["about"]["links"] if entry["category"] == "project"]
         return self.projects
 
     def get_object(self, object_id, project_id=None):
@@ -595,10 +581,9 @@ class GoodData:
         export_job = self.partial_export_async(object_id)
         export_job.wait()
 
-    ## TODO: Is there a way to monitor status? I don't have a project to test this in right now
     def partial_import_async(self, token, target_pid=None):
         """Create partial import job and return (before job completes)
-        Returns True on 200 status code, False on any other
+        Returns ExportJob to enable polling status, None if import failed
 
         Args:
             token (str): Token of export job to be imported
@@ -622,7 +607,7 @@ class GoodData:
         response = self.session.post(url, headers=self.headers, data=json.dumps(body))
         ## OK
         if response.status_code == 200:
-            return True
+            return ExportJob(None, response.json()["uri"], gd)
         ## Too Many Requests
         if response.status_code == 429:
             self.logger.warning(
@@ -633,7 +618,7 @@ class GoodData:
             return self.partial_import_async(token, target_pid)
         self.logger.error("Returned non-200 status code: %d", response.status_code)
         self.logger.error(response.text)
-        return False
+        return None
 
     def get_report_by_identifier(self, identifier, project_id=None, object_name="reports"):
         """Get report or visualizationobject by identifier.
